@@ -3,6 +3,7 @@ use crate::models::works::Work;
 use crate::OpenLibraryClient;
 use reqwest::{Method, Url};
 use std::error::Error;
+use std::str::FromStr;
 use wiremock::matchers::{method, path};
 use wiremock::{Mock, MockServer, ResponseTemplate};
 
@@ -13,7 +14,7 @@ async fn test_works_get_returns_success() -> Result<(), Box<dyn Error>> {
         .with_host(Url::parse(server.uri().as_str())?)
         .build()?;
 
-    let mock_work_identifier = OpenLibraryIdentifer::from("OL92304270")?;
+    let mock_work_identifier = OpenLibraryIdentifer::from_str("OL92304270")?;
     let mock_response: Work = serde_json::from_str(include_str!("resources/work.json"))?;
 
     Mock::given(method(Method::GET.as_str()))
